==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Block/ts/Block_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>Block</name>
    <message>
        <location filename="../Block.js" line="+67"/>
        <source>Block Tools</source>
        <translation>Herramientas de bloque</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show block tools</source>
        <translation>Mostrar las herramientas de bloque</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;Block</source>
        <translation>&amp;Bloque</translation>
    </message>
</context>
<context>
    <name>BlockDialog</name>
    <message>
        <location filename="../BlockDialog.ui" line="+17"/>
        <source>Block Data</source>
        <translation>Datos del bloque</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Block name:</source>
        <translation>Nombre del Bloque:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>block 1</source>
        <translation>block 1</translation>
    </message>
    <message>
        <location filename="../BlockDialog.js" line="+115"/>
        <source>Leading or trailing spaces.</source>
        <translation>Espacios iniciales o finales.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block name is empty.</source>
        <translation>Nombre del bloque está vacío.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block name is invalid.</source>
        <translation>Nombre del bloque no es válida.</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Block &apos;%1&apos; already exists&lt;br&gt;and will be overwritten.</source>
        <translation>Bloquear &quot;%1&quot; ya existe&lt;br&gt;y se sobrescribirá.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block already exists.</source>
        <translation>Bloque ya existe.</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Block/ts/Block_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>Block</name>
    <message>
        <location filename="../Block.js" line="+67"/>
        <source>Block Tools</source>
        <translation>Herramientas de bloque</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show block tools</source>
        <translation>Mostrar las herramientas de bloque</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;Block</source>
        <translation>&amp;Bloque</translation>
    </message>
</context>
<context>
    <name>BlockDialog</name>
    <message>
        <location filename="../BlockDialog.ui" line="+17"/>
        <source>Block Data</source>
        <translation>Datos del bloque</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Block name:</source>
        <translation>Nombre del Bloque:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>block 1</source>
        <translation>block 1</translation>
    </message>
    <message>
        <location filename="../BlockDialog.js" line="+134"/>
        <source>Leading or trailing spaces.</source>
        <translation>Espacios iniciales o finales.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block name is empty.</source>
        <translation>Nombre del bloque está vacío.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block name is invalid.</source>
        <translation>Nombre del bloque no es válida.</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Block &apos;%1&apos; already exists&lt;br&gt;and will be overwritten.</source>
        <translation>Bloquear &quot;%1&quot; ya existe&lt;br&gt;y se sobrescribirá.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block already exists.</source>
        <translation>Bloque ya existe.</translation>
    </message>
</context>
<context>
    <name>LayoutDialog</name>
    <message>
        <source>Layout</source>
        <translation type="vanished">Presentación</translation>
    </message>
    <message>
        <source>Leading or trailing spaces.</source>
        <translation type="vanished">Espacios iniciales o finales.</translation>
    </message>
    <message>
        <source>Layout name is empty.</source>
        <translation type="vanished">Nombre del presentación está vacío.</translation>
    </message>
    <message>
        <source>Layout name is invalid.</source>
        <translation type="vanished">Nombre del presentación no es válida.</translation>
    </message>
    <message>
        <source>Layout &apos;%1&apos; already exists&lt;br&gt;and will be overwritten.</source>
        <translation type="vanished">Presentación &quot;%1&quot; ya existe&lt;br&gt;y se sobrescribirá.</translation>
    </message>
    <message>
        <source>Layout already exists.</source>
        <translation type="vanished">Presentación ya existe.</translation>
    </message>
    <message>
        <source>Layout Data</source>
        <translation type="vanished">Datos del presentación</translation>
    </message>
    <message>
        <source>Layout name:</source>
        <translation type="vanished">Nombre del presentación:</translation>
    </message>
</context>
</TS>
